@@ -172,6 +172,9 @@ Joins array ref of characters to a space-separated string.
 
 =head1 SEE ALSO
 
+There is a mailing list at L<https://groups.google.com/forum/#!forum/bio-phylo> 
+for any user or developer questions and discussions.
+
 =over
 
 =item L<Bio::Phylo::Matrices::Datatype>
