@@ -104,6 +104,9 @@ Tests if argument can be inserted in invocant.
 
 =head1 SEE ALSO
 
+There is a mailing list at L<https://groups.google.com/forum/#!forum/bio-phylo> 
+for any user or developer questions and discussions.
+
 Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>.
 
 Consult the documentation for L<Bio::Phylo::Listable/SETS MANAGEMENT> for more info 
