@@ -117,6 +117,9 @@ TEMPLATE
 
 =head1 SEE ALSO
 
+There is a mailing list at L<https://groups.google.com/forum/#!forum/bio-phylo> 
+for any user or developer questions and discussions.
+
 =over
 
 =item L<Bio::Phylo::IO>
