@@ -66,6 +66,9 @@ BEGIN {
       _NS_FIGTREE_
       _NS_PHYLOMAP_
       _NS_BIOVEL_
+      _NS_NHX_
+      _NS_DWC_
+      _NS_GBIF_
     );
     %EXPORT_TAGS = (
         'all'         => [@EXPORT_OK],
@@ -135,6 +138,9 @@ BEGIN {
               _NS_FIGTREE_
               _NS_PHYLOMAP_
               _NS_BIOVEL_
+              _NS_NHX_
+              _NS_DWC_
+              _NS_GBIF_
             )
         ]
     );
@@ -162,8 +168,11 @@ sub _NS_PHYLOXML_ () { 'http://www.phyloxml.org/1.10/terms#' }
 sub _NS_TB2PURL_ ()  { 'http://purl.org/phylo/treebase/phylows/' }
 sub _NS_TNRS_ ()     { 'http://phylotastic.org/tnrs/terms#' }
 sub _NS_FIGTREE_ ()  { 'http://tree.bio.ed.ac.uk/software/figtree/terms#' }
-sub _NS_PHYLOMAP_ () { 'http://purl.org/phylo/phylomap/terms#' }
+sub _NS_PHYLOMAP_ () { 'http://phylomap.org/terms.owl#' }
 sub _NS_BIOVEL_ ()   { 'http://biovel.eu/terms#' }
+sub _NS_NHX_ ()      { 'http://sites.google.com/site/cmzmasek/home/software/forester/nhx' }
+sub _NS_DWC_ ()      { 'http://rs.tdwg.org/dwc/terms/' }
+sub _NS_GBIF_ ()     { 'http://rs.gbif.org/terms/1.0/' }
 
 our $NS = {
     'tnrs' => _NS_TNRS_(),
@@ -183,6 +192,9 @@ our $NS = {
     'bv'   => _NS_BIOVEL_(),
     'dcterms' => _NS_DCTERMS_(),
     'fig'     => _NS_FIGTREE_(),
+    'nhx'     => _NS_NHX_(),
+    'dwc'     => _NS_DWC_(),
+    'gbif'    => _NS_GBIF_(),
 };
 
 sub _NEXML_VERSION_ () { '0.9' }
