@@ -1,13 +1,23 @@
 package Bio::Phylo::Util::Logger;
 use strict;
 use base 'Exporter';
+use Term::ANSIColor;
 use Bio::Phylo::Util::Exceptions 'throw';
 use Bio::Phylo::Util::CONSTANT qw'/looks_like/';
 
-our ( %VERBOSITY, $PREFIX );
+our ( %VERBOSITY, $PREFIX, %STYLE );
+our $STYLE       = 'detailed';
+our $COLORED     = 1; # new default: we use colors
 our $TRACEBACK   = 0;
 our @EXPORT_OK   = qw(DEBUG INFO WARN ERROR FATAL VERBOSE);
 our %EXPORT_TAGS = ( 'simple' => [@EXPORT_OK], 'levels' => [@EXPORT_OK] );
+our %COLORS      = (
+	'DEBUG' => 'blue', 
+	'INFO'  => 'green',
+	'WARN'  => 'yellow',
+	'ERROR' => 'bold red',
+	'FATAL' => 'red',
+);
 
 BEGIN {
     
@@ -22,11 +32,25 @@ BEGIN {
     
     # set verbosity to 2, i.e. warn
     $VERBOSITY{'*'} = $ENV{'BIO_PHYLO_VERBOSITY'} || 2;
+    
+    # define verbosity styles
+    %STYLE = (
+    	'simple'   => '${level}: $message',
+    	'detailed' => '$level $sub [$file $line] - $message',    
+    );
 }
 
 {
     my %levels = ( FATAL => 0, ERROR => 1, WARN => 2, INFO => 3, DEBUG => 4 );
-    my @listeners = ( sub { print STDERR shift } ); # default
+    my @listeners = ( sub {
+    	my ( $string, $level ) = @_;
+    	if ( $COLORED and -t STDERR ) {
+    		print STDERR colored( $string, $COLORS{$level} ); 
+    	}
+    	else {
+    		print STDERR $string;
+    	}
+    } ); # default
 
     # dummy constructor that dispatches to VERBOSE(),
     # then returns the package name
@@ -53,31 +77,32 @@ BEGIN {
     # this is never called directly. rather, messages are dispatched here
     # by the DEBUG() ... FATAL() subs below
     sub LOG ($$) {
-        my ( $msg, $lvl ) = @_;
+        my ( $message, $level ) = @_;
         
         # probe the call stack
-        my ( $pack2, $file2, $line2, $sub2 ) = caller( $TRACEBACK + 2 );
-        my ( $pack1, $file1, $line1, $sub1 ) = caller( $TRACEBACK + 1 );
+        my ( $pack2, $file2, $line2, $sub  ) = caller( $TRACEBACK + 2 );
+        my ( $pack1, $file,  $line,  $sub1 ) = caller( $TRACEBACK + 1 );
         
         # cascade verbosity from global to local
         my $verbosity = $VERBOSITY{'*'}; # global
         $verbosity = $VERBOSITY{$pack1} if exists $VERBOSITY{$pack1}; # package
-        $verbosity = $VERBOSITY{$sub2}  if exists $VERBOSITY{$sub2}; # sub
+        $verbosity = $VERBOSITY{$sub}  if $sub and exists $VERBOSITY{$sub}; # sub
         
         # verbosity is higher than the current caller, proceed
-        if ( $verbosity >= $levels{$lvl} ) {            
+        if ( $verbosity >= $levels{$level} ) {            
 
             # strip the prefix from the calling file's path
-            if ( index $file1, $PREFIX == 0 ) {
-                $file1 =~ s/^\Q$PREFIX\E//;
+            if ( index($file, $PREFIX) == 0 ) {
+                $file =~ s/^\Q$PREFIX\E//;
             }
             
-            # make template, populate string
-            my $tmpl = "%s %s [%s: %i] - %s\n";
-            my $string = sprintf $tmpl, $lvl, $sub2, $file1, $line1, $msg;
+            # select one of the templates
+            my $string;
+            my $s = $STYLE{$STYLE};
+            $string = eval "qq[$s\n]";
             
             # dispatch to the listeners
-            $_->( $string, $lvl, $sub2, $file1, $line1, $msg ) for @listeners;
+            $_->( $string, $level, $sub, $file, $line, $message ) for @listeners;
         }       
     }
     
@@ -166,17 +191,72 @@ BEGIN {
                 __PACKAGE__->PREFIX($opt{'-prefix'});
             }
             
+            # set logstyle
+            if ( $opt{'-style'} ) {
+            	my $s = lc $opt{'-style'};
+            	if ( exists $STYLE{$s} ) {
+            		$STYLE = $s;
+            	}
+            } 
+            
+            # turn colors on/off. default is on.
+            $COLORED = !!$opt{'-colors'} if defined $opt{'-colors'};
         }
         return $VERBOSITY{'*'};
     }
     
-    # alias for singleton methods
-    no warnings 'once';
-    *fatal = \&FATAL;
-    *error = \&ERROR;
-    *warn  = \&WARN;
-    *info  = \&INFO;
-    *debug = \&DEBUG;
+    # Change the terminal to a predefined color. For example to make sure that
+    # an entire exception (or part of it) is marked up as FATAL, or so that the
+    # output from an external command is marked up as DEBUG.
+    sub start_color {
+    	my ( $self, $level, $handle ) = @_;
+    	$handle = \*STDERR if not $handle;    	
+    	if ( $COLORED and -t $handle ) {
+    		print $handle color $COLORS{$level}; 
+    	}
+    	return $COLORS{$level};
+    }
+    
+    sub stop_color {
+    	my ( $self, $handle ) = @_;
+    	$handle = \*STDERR if not $handle;    	
+    	if ( $COLORED and -t $handle ) {
+    		print $handle color 'reset'; 
+    	} 
+    	return $self;   
+    }    
+    
+    # aliases for singleton methods
+    sub fatal {
+		my $self = shift;
+		$TRACEBACK++;
+		FATAL shift;
+		$TRACEBACK--;
+	}
+    sub error {
+		my $self = shift;
+		$TRACEBACK++;
+		ERROR shift;
+		$TRACEBACK--;
+	}
+	sub warn {
+		my $self = shift;
+		$TRACEBACK++;
+		WARN shift;
+		$TRACEBACK--;
+	}
+	sub info {
+		my $self = shift;
+		$TRACEBACK++;
+		INFO shift;
+		$TRACEBACK--;
+	}
+	sub debug {
+		my $self = shift;
+		$TRACEBACK++;
+		DEBUG shift;
+		$TRACEBACK--;
+	}
     
     # empty destructor so we don't go up inheritance tree at the end
     sub DESTROY {}  
@@ -414,6 +494,32 @@ Adds listeners to send log messages to.
            $line,       # line where log method was called
            $msg         # the unformatted message
 
+=item start_color()
+
+Changes color of output stream to that of specified logging level. This so that for 
+example all errors are automatically marked up as 'FATAL', or all output generated
+by an external program is marked up as 'DEBUG'
+
+ Type    : Mutator
+ Title   : start_color()
+ Usage   : $logger->start_color( 'DEBUG', \*STDOUT )
+ Function: Changes color of output stream
+ Returns : color name
+ Args    : Log level whose color to use, 
+           (optional) which stream to change, default is STDERR
+
+=item stop_color()
+
+Resets the color initiated by start_color()
+
+ Type    : Mutator
+ Title   : stop_color()
+ Usage   : $logger->stop_color( \*STDOUT )
+ Function: Changes color of output stream
+ Returns : color name
+ Args    : (Optional) which stream to reset, default is STDERR
+
+
 =item PREFIX()
 
 Getter and setter of path prefix to strip from source file paths in messages.
